@@ -5,9 +5,8 @@ import logging
 
 __author__ = "Tamara Khalbashkeeva"
 __license__ = "BSD"
-__version__ = '0.0.1a'
+__version__ = '0.0.2'
 __email__ = "infinityxxx@gmail.com"
-__status__ = "Alpha"
 
 
 class NullHandler(logging.Handler):
